#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client-core
version:              0.20.3.0
visibility:           public
id:                   servant-client-core-0.20.3.0-7oODArJ9N48DvjBb0UYpVr
key:                  servant-client-core-0.20.3.0-7oODArJ9N48DvjBb0UYpVr
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  f684310c323f59fde7d9eed39259b9b1
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.MultiVerb.ResponseUnrender
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Core.ServerSentEvents Servant.Client.Free
    Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.20.3.0-7oODArJ9N48DvjBb0UYpVr
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    base64-bytestring-1.2.1.0-7JruMLJLgBF2cqlGBjJEVX
    bytestring-0.11.5.3 constraints-0.14.3-1N3MurVNq0AD0HnTYsI7gS
    containers-0.6.7 deepseq-1.4.8.1 exceptions-0.10.7
    free-5.2-FFpqSvOPnCIFVyqDHAaUKG
    http-media-0.8.1.1-D2N5K0d96ptKZh8QUt7tZ0
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    network-uri-2.6.4.2-DXIr6FO81fkKKSx83uC4Cz
    safe-0.3.21-Hishw766JFf9X5XLYDU9sV
    servant-0.20.3.0-9GSVLIq6JVd9kiQ6AqKBni
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

